import { jsx as _jsx } from "react/jsx-runtime";
import { Dropdown } from "../primitives/dropdown.js";
import { PropertyLine } from "./propertyLine.js";
/**
 * Wraps a dropdown in a property line
 * @param props - PropertyLineProps and DropdownProps
 * @returns property-line wrapped dropdown
 */
const DropdownPropertyLine = (props) => {
    return (_jsx(PropertyLine, { ...props, children: _jsx(Dropdown, { ...props }) }));
};
export const NullableDropdownPropertyLine = (props) => (_jsx(DropdownPropertyLine, { ...props, includeNullAs: "null" }));
const OptionalDropdownPropertyLine = (props) => _jsx(DropdownPropertyLine, { ...props, includeNullAs: "undefined" });
/**
 * Dropdown component for explicitly defined number values.
 * If value can be undefined, use OptionalNumberDropdownPropertyLine instead.
 * If value can be null, use NullableNumberDropdownPropertyLine instead.
 */
export const NumberDropdownPropertyLine = DropdownPropertyLine;
/**
 * Dropdown component for explicitly defined string values.
 * If value can be undefined, use OptionalStringDropdownPropertyLine instead.
 * If value can be null, use NullableStringDropdownPropertyLine instead.
 */
export const StringDropdownPropertyLine = DropdownPropertyLine;
/**
 * Dropdown component for Nullable<number> values.
 */
export const NullableNumberDropdownPropertyLine = NullableDropdownPropertyLine;
/**
 * Dropdown component for Nullable<string> values.
 */
export const NullableStringDropdownPropertyLine = NullableDropdownPropertyLine;
/**
 * Dropdown component for number | undefined values
 */
export const OptionalNumberDropdownPropertyLine = OptionalDropdownPropertyLine;
/**
 * Dropdown component for string | undefined values
 */
export const OptionalStringDropdownPropertyLine = OptionalDropdownPropertyLine;
//# sourceMappingURL=dropdownPropertyLine.js.map