import type { FunctionComponent } from "react";
import type { BaseComponentProps, PropertyLineProps } from "./propertyLine.js";
import { Quaternion, Vector4 } from "@babylonjs/core/Maths/math.vector.js";
import type { Vector3 } from "@babylonjs/core/Maths/math.vector.js";
export type TensorPropertyLineProps<V extends Vector3 | Vector4 | Quaternion> = BaseComponentProps<V> & PropertyLineProps & {
    /**
     * If passed, all sliders will use this for the min value
     */
    min?: number;
    /**
     * If passed, all sliders will use this for the max value
     */
    max?: number;
    /**
     * If passed, the UX will use the conversion functions to display/update values
     */
    valueConverter?: {
        /**
         * Will call from(val) before displaying in the UX
         */
        from: (val: number) => number;
        /**
         * Will call to(val) before calling onChange
         */
        to: (val: number) => number;
    };
};
type RotationVectorPropertyLineProps = TensorPropertyLineProps<Vector3> & {
    /**
     * Display angles as degrees instead of radians
     */
    useDegrees?: boolean;
};
export declare const RotationVectorPropertyLine: FunctionComponent<RotationVectorPropertyLineProps>;
type QuaternionPropertyLineProps = TensorPropertyLineProps<Quaternion> & {
    /**
     * Display angles as degrees instead of radians
     */
    useDegrees?: boolean;
};
export declare const QuaternionPropertyLine: FunctionComponent<QuaternionPropertyLineProps>;
export declare const Vector3PropertyLine: FunctionComponent<TensorPropertyLineProps<Vector3>>;
export declare const Vector4PropertyLine: FunctionComponent<TensorPropertyLineProps<Vector4>>;
export {};
