import { jsx as _jsx, jsxs as _jsxs } from "react/jsx-runtime";
import { Children, isValidElement, useMemo } from "react";
import { Accordion as FluentAccordion, AccordionItem, AccordionHeader, AccordionPanel, Subtitle1, makeStyles, tokens } from "@fluentui/react-components";
const useStyles = makeStyles({
    accordion: {
        overflowX: "hidden",
        overflowY: "auto",
        paddingBottom: tokens.spacingVerticalM,
        display: "flex",
        flexDirection: "column",
        rowGap: tokens.spacingVerticalM,
    },
    panelDiv: {
        display: "flex",
        flexDirection: "column",
        overflow: "hidden",
    },
});
export const AccordionSection = (props) => {
    const classes = useStyles();
    return _jsx("div", { className: classes.panelDiv, children: props.children });
};
export const Accordion = (props) => {
    const classes = useStyles();
    const { children, ...rest } = props;
    const validChildren = useMemo(() => {
        return (Children.map(children, (child) => {
            if (isValidElement(child)) {
                const childProps = child.props;
                if (childProps.title) {
                    return {
                        title: childProps.title,
                        collapseByDefault: childProps.collapseByDefault,
                        content: child,
                    };
                }
            }
            return null;
        })?.filter(Boolean) ?? []);
    }, [children]);
    return (_jsx(FluentAccordion, { className: classes.accordion, collapsible: true, multiple: true, defaultOpenItems: validChildren.filter((child) => !child.collapseByDefault).map((child) => child.title), ...rest, children: validChildren.map((child) => {
            return (_jsxs(AccordionItem, { value: child.title, children: [_jsx(AccordionHeader, { expandIconPosition: "end", children: _jsx(Subtitle1, { children: child.title }) }), _jsx(AccordionPanel, { children: _jsx("div", { className: classes.panelDiv, children: child.content }) })] }, child.title));
        }) }));
};
//# sourceMappingURL=accordion.js.map