import { jsx as _jsx } from "react/jsx-runtime";
import { Dropdown as FluentDropdown, makeStyles, Option } from "@fluentui/react-components";
import { useEffect, useState } from "react";
const useDropdownStyles = makeStyles({
    dropdownOption: {
        textAlign: "right",
        minWidth: "40px",
    },
    optionsLine: {},
});
/**
 * Renders a fluent UI dropdown component for the options passed in, and an additional 'Not Defined' option if null is set to true
 * This component can handle both null and undefined values
 * @param props
 * @returns dropdown component
 */
export const Dropdown = (props) => {
    const classes = useDropdownStyles();
    // This component can handle both null and undefined values, so '==' null is intentionally used throughout to check for both cases.
    const [options] = useState(props.includeNullAs ? [{ label: "<Not defined>", value: Number.MAX_SAFE_INTEGER }, ...props.options] : props.options);
    const [defaultVal, setDefaultVal] = useState(props.value == null ? Number.MAX_SAFE_INTEGER : props.value);
    useEffect(() => {
        setDefaultVal(props.value == null ? Number.MAX_SAFE_INTEGER : props.value);
    }, [props.value]);
    return (_jsx(FluentDropdown, { size: "small", className: classes.dropdownOption, onOptionSelect: (evt, data) => {
            const value = typeof props.value === "number" ? Number(data.optionValue) : data.optionValue;
            if (value !== undefined) {
                setDefaultVal(value);
                const nullVal = props.includeNullAs === "null" ? null : undefined;
                value === Number.MAX_SAFE_INTEGER ? props.onChange(nullVal) : props.onChange(value);
            }
        }, selectedOptions: [defaultVal.toString()], value: options.find((o) => o.value === defaultVal)?.label, children: options.map((option) => (_jsx(Option, { className: classes.optionsLine, value: option.value.toString(), disabled: false, children: option.label }, option.label))) }));
};
//# sourceMappingURL=dropdown.js.map